<?xml version="1.0" encoding="UTF-8"?><sch:schema 
    xmlns:sch="http://purl.oclc.org/dsdl/schematron" 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:fct="localFunctions" queryBinding="xslt2" 
    id="NTDB" schemaVersion="2020" see="URL to human-readable documentation for this document">

 <sch:ns prefix="fct" uri="localFunctions"/>
 
 
<xsl:function name="fct:parseDate" as="xs:string">
	<xsl:param name="input"/>
	<xsl:choose>
		<xsl:when test="$input castable as xs:date">
			<xsl:value-of select="$input"/>
		</xsl:when>
		<xsl:when test="$input castable as xs:string">
			<xsl:choose>
				<xsl:when test="string-length($input)=8">
					<xsl:variable name="year" as="xs:string" select="substring($input,1,4)"/>
					<xsl:variable name="month" as="xs:string" select="substring($input,5,2)"/>
					<xsl:variable name="day" as="xs:string" select="substring($input,7,2)"/>
					<xsl:value-of select="string-join(($year,$month,$day),'-')"/>		
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="''"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="''"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>


<xsl:function name="fct:notLessThanDate" as="xs:boolean">
	<xsl:param name="firstDate"/>
	<xsl:param name="secondDate"/>
	<xsl:variable name="firstDateMod" select="fct:parseDate($firstDate)"/>
	<xsl:variable name="secondDateMod" select="fct:parseDate($secondDate)"/>
		<xsl:choose>
		<xsl:when test="($firstDateMod castable as xs:date) and ($secondDateMod castable as xs:date) ">
			<xsl:value-of select="not(xs:date($firstDateMod) &lt; xs:date($secondDateMod))"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="true()"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>

<xsl:function name="fct:notEqualDate" as="xs:boolean">
	<xsl:param name="firstDate"/>
	<xsl:param name="secondDate"/>
	<xsl:variable name="firstDateMod" select="fct:parseDate($firstDate)"/>
	<xsl:variable name="secondDateMod" select="fct:parseDate($secondDate)"/>
	<xsl:choose>
		<xsl:when test="($firstDateMod castable as xs:date) and ($secondDateMod castable as xs:date)">
			<xsl:value-of select="not(xs:date($firstDateMod) = xs:date($secondDateMod))"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="true()"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>


<xsl:function name="fct:padTime" as="xs:time">
	<xsl:param name="input" as="xs:string"/>
	<xsl:choose>
		<xsl:when test="$input castable as xs:time">
			<xsl:value-of select="$input"/>
		</xsl:when>
		<xsl:when test="string-length($input)=5">
			<xsl:value-of select="string-join(($input,'00'), ':')"/>
		</xsl:when>
		<xsl:when test="string-length($input)=6">
			<xsl:variable name="hours" as="xs:string" select="substring($input,1,2)"/>
			<xsl:variable name="minutes" as="xs:string" select="substring($input,3,2)"/>
			<xsl:variable name="seconds" as="xs:string" select="substring($input,5,2)"/>
			<xsl:value-of select="string-join(($hours,$minutes,$seconds),':')"/>
		</xsl:when>
		<xsl:when test="string-length($input)=4">
			<xsl:variable name="hours" as="xs:string" select="substring($input,1,2)"/>
			<xsl:variable name="minutes" as="xs:string" select="substring($input,3,2)"/>
			<xsl:variable name="seconds" as="xs:string" select="'00'"/>
			<xsl:value-of select="string-join(($hours,$minutes,$seconds),':')"/>
		</xsl:when>		
		<xsl:otherwise>
			<xsl:value-of select="''"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>

<xsl:function name="fct:notLessThanTime" as="xs:boolean">
	<xsl:param name="firstTime" as="xs:string?"/>
	<xsl:param name="secondTime" as="xs:string?"/>
	<xsl:choose>
		<xsl:when test="$firstTime = '' or not($firstTime)">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:when test="$secondTime = '' or not($secondTime)">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:when test="not(xs:time(fct:padTime($firstTime)) &lt; xs:time(fct:padTime($secondTime)))">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="false()"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>

<xsl:function name="fct:notEqualTime" as="xs:boolean">
	<xsl:param name="firstTime" as="xs:string?"/>
	<xsl:param name="secondTime" as="xs:string?"/>
	<xsl:choose>
		<xsl:when test="$firstTime = '' or not($firstTime)">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:when test="$secondTime = '' or not($secondTime)">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:when test="not(xs:time(fct:padTime($firstTime)) = xs:time(fct:padTime($secondTime)))">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="false()"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>


<xsl:function name="fct:matches" as="xs:boolean">
	<xsl:param name="data" as="xs:string"/>
	<xsl:param name="regex" as="xs:string"/>
	<xsl:choose>
		<xsl:when test="matches($data,$regex)">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="false()"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>


<xsl:function name="fct:durationParse" as="xs:integer">
	<xsl:param name="startDate"/>
	<xsl:param name="endDate"/>
	<xsl:param name="type" as="xs:string"/>
	<xsl:variable name="startDateMod" select="fct:parseDate($startDate)"/>
	<xsl:variable name="endDateMod" select="fct:parseDate($endDate)"/>

	<xsl:choose>
		<xsl:when test="($startDateMod castable as xs:date) and ($endDateMod castable as xs:date)">
			<xsl:variable name="startDateModYear" select="year-from-date(xs:date($startDateMod))"/>
			<xsl:variable name="startDateModMonth" select="month-from-date(xs:date($startDateMod))"/>
			<xsl:variable name="startDateModDay" select="day-from-date(xs:date($startDateMod))"/>
			<xsl:variable name="endDateModYear" select="year-from-date(xs:date($endDateMod))"/>
			<xsl:variable name="endDateModMonth" select="month-from-date(xs:date($endDateMod))"/>
			<xsl:variable name="endDateModDay" select="day-from-date(xs:date($endDateMod))"/>
			<xsl:choose>
				<xsl:when test="$type = '5'">
					<xsl:value-of select="xs:integer((xs:date($endDateMod) - xs:date($startDateMod)) div xs:dayTimeDuration('PT1M'))"/>
				</xsl:when>
		
				<xsl:when test="$type = '1'">
					<xsl:value-of select="xs:integer((xs:date($endDateMod) - xs:date($startDateMod)) div xs:dayTimeDuration('PT1H'))"/>
				</xsl:when>
	
				<xsl:when test="$type = '2'">
					<xsl:value-of select="xs:integer((xs:date($endDateMod) - xs:date($startDateMod)) div xs:dayTimeDuration('P1D'))"/>
				</xsl:when>
		
				<xsl:when test="$type = '3'">
					<xsl:choose>
						<xsl:when test="$endDateModDay &lt; $startDateModDay">
							<xsl:value-of select="$endDateModMonth - $startDateModMonth - 1"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="($endDateModMonth - $startDateModMonth) + 12 * ($endDateModYear - $startDateModYear)"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
			
				<xsl:when test="$type = '4'">
					<xsl:choose>
						<xsl:when test="$endDateModMonth &lt; $startDateModMonth">
							<xsl:value-of select="$endDateModYear - $startDateModYear - 1"/>
						</xsl:when>
						<xsl:when test="($endDateModMonth = $startDateModMonth) and ($endDateModDay &lt; $startDateModDay)">
							<xsl:value-of select="$endDateModYear - $startDateModYear - 1"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$endDateModYear - $startDateModYear"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="-1"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>		
		<xsl:otherwise>
			<xsl:value-of select="-1"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>

<xsl:function name="fct:getYear" as="xs:integer">
	<xsl:param name="date"/>
	<xsl:variable name="dateMod">
		<xsl:choose>
			<xsl:when test="$date castable as xs:date">
				<xsl:value-of select="$date"/>
			</xsl:when>
			<xsl:when test="$date castable as xs:string">
				<xsl:value-of select="fct:parseDate($date)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$date"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="$dateMod castable as xs:date">
			<xsl:value-of select="year-from-date($dateMod)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="0"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>

  <sch:title>NTDB ISO Schematron file</sch:title>

  <sch:ns prefix="ntdb" uri="PLACEHOLDER"/>
  <sch:ns prefix="xsi" uri="http://www.w3.org/2001/XMLSchema-instance"/>

  
  
  <sch:let name="ntdbElements" value="()"/>
  <sch:let name="ntdbElementsMissing" value="''"/>


  
  
<sch:pattern id="DSHS_ID_Check">  
	<sch:title>DSHS ID check</sch:title>
	<sch:rule id="DSHS_ID" context="FacilityId">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C001_FacilityId" role="[ERROR]" diagnostics="ntdbDiagnostic" test="string-length(.)=7">
			C001: DSHS IDs for Hospitals must be 7 digits long.  Please include leading zeroes if needed.
		</sch:assert>
	</sch:rule>
</sch:pattern>

<sch:pattern id="whole record check">
	<sch:title>whole record check</sch:title>
	<sch:rule id="Whole_Record" context="TX_Extensions">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C002_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="./TX_PatientFirstName != ''">
			C002: First name cannot be blank or null value
		</sch:assert>
		<sch:assert id="C003_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="./TX_PatientLastName != ''">
			C003: Last name cannot be blank or null value
		</sch:assert>
	</sch:rule>
</sch:pattern>

<sch:pattern id="patient ID">
	<sch:title>patient ID</sch:title>
	<sch:rule id="Patient_ID" context="PatientId">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C004_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="string-length(.) &lt;= 18">
			C004: PatientId cannot be more than 18 digits.
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C005_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="matches(., '[0-9]{1,18}')">
			C005: PatientId must be only digits.
		</sch:assert>
	</sch:rule>
</sch:pattern>

<sch:pattern id="RfFacility ID">
	<sch:title>Reference Facility Id</sch:title>
	<sch:rule id="TX_RfFacilityId" context="TX_RfFacilityId">
                <sch:let name="ntdbElements" value="."/>
		<sch:assert id="C006_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(true()) else(matches(., '[0-9]'))">
			C006: (TX_RfFacilityId) Reference hospital number must be only digits.
		</sch:assert>
                
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C007_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2') or string-length(.) = 7) then(true()) else(false())">
			C007: (TX_RfFacilityId) Reference hospital number must be 7 digits long. Please include leading zeroes if needed.
		</sch:assert>
		
	</sch:rule>
</sch:pattern>

<sch:pattern id="DischargeToFacility ID">
	<sch:title>Discharged To Facility Name</sch:title>
	<sch:rule id="TX_DischargeToFacilityId" context="TX_DischargeToFacilityId">
        <sch:let name="ntdbElements" value="."/>
		<sch:assert id="C008_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(true()) else(matches(., '[0-9]'))">
			C008: (TX_DischargeToFacilityId) Discharged To Facility number must be only digits.
        </sch:assert>
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C009_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2') or string-length(.) = 7) then(true()) else(false())">
			C009: (TX_DischargeToFacilityId) Discharged To Facility number must be 7 digits long. Please include leading zeroes if needed.
		</sch:assert>
	</sch:rule>
</sch:pattern>

<sch:pattern id="PhProviderAgency ID">
	<sch:title>Pre Hospital EMS Name</sch:title>
	<sch:rule id="TX_PhProviderAgencyId" context="TX_PhProviderAgencyId">
                <sch:let name="ntdbElements" value="."/>
		<sch:assert id="C010_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(true()) else(matches(., '[0-9]'))">
			C010: (TX_PhProviderAgencyId) Pre Hospital EMS number must be only digits.
		</sch:assert>
                
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C011_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2') or string-length(.) = 6) then(true()) else(false())">
			C011: (TX_PhProviderAgencyId) Pre Hospital EMS number must be 6 digits long. Please include leading zeroes if needed.
		</sch:assert>
	</sch:rule>
</sch:pattern>

<sch:pattern id="TransferHospitalEms ID">
	<sch:title>Transfer Hospital EMS Name</sch:title>
	<sch:rule id="TX_TransferHospitalEmsId" context="TX_TransferHospitalEmsId">
                <sch:let name="ntdbElements" value="."/>
		<sch:assert id="C012_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(true()) else(matches(., '[0-9]'))">
			C012: (TX_TransferHospitalEmsId) Transfer Hospital EMS number must be only digits.
		</sch:assert>
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C013_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2') or string-length(.) = 6) then(true()) else(false())">
			C013: (TX_TransferHospitalEmsId) Transfer Hospital EMS number must be 6 digits long. Please include leading zeroes if needed.
		</sch:assert>
		
	</sch:rule>
</sch:pattern>
<sch:pattern id="HospitalProcedure Location">
	<sch:title>Hospital Procedure Location</sch:title>
	<sch:rule id="HospitalProcedureLocation" context="HospitalProcedureLocation">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C014_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(true()) else(matches(., '[0-9]'))">
			C014: (HospitalProcedureLocation) Hospital Procedure Location value must be a digit.
		</sch:assert>
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C015_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(true()) else(. &gt;= 1 and . &lt;= 7)">
			C015: (HospitalProcedureLocation) Hospital Procedure Location value must be between 1 and 7 (inclusive).
		</sch:assert>
	</sch:rule>
</sch:pattern>
<sch:pattern id="Injury Type">
	<sch:title>Injury Type</sch:title>
	<sch:rule id="TX_InjuryType" context="TX_InjuryType">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C016_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(true()) else(matches(., '[0-9]'))">
			C016: (TX_InjuryType) Injury Type value must be a digit.
		</sch:assert>
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C017_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(true()) else(. &gt;= 1 and . &lt;= 4)">
			C017: (TX_InjuryType) Injury Type value must be between 1 and 4 (inclusive).
		</sch:assert>
	</sch:rule>
</sch:pattern>
<sch:pattern id="Injury Mechanism">
	<sch:title>Injury Mechanism</sch:title>
	<sch:rule id="TX_InjuryMechanism" context="TX_InjuryMechanism">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C018_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(true()) else(matches(., '[0-9]'))">
			C018: (TX_InjuryMechanism) Injury Mechanism value must be a digit.
		</sch:assert>
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="C019_Whole" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(true()) else(. &gt;= 1 and . &lt;= 26)">
			C019: (TX_InjuryMechanism) Injury Mechanism value must be between 1 and 26 (inclusive).
		</sch:assert>
	</sch:rule>
</sch:pattern>

  

  <sch:diagnostics>

    

    <sch:diagnostic id="ntdbDiagnostic">
	<ntdbDiagnostic xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
		<record>
			<xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
			<xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
		</record>
		<elements>
			<xsl:for-each select="$ntdbElements">
				<xsl:element name="element">
					<xsl:attribute name="location">
						<xsl:apply-templates select="." mode="schematron-get-full-path"/>
					</xsl:attribute>
					<xsl:for-each select="@*">
						<xsl:attribute name="{name()}">
							<xsl:value-of select="."/>
						</xsl:attribute>
					</xsl:for-each>
					<xsl:if test="not(*)">
						<xsl:value-of select="."/>
					</xsl:if>
				</xsl:element>
			</xsl:for-each>
		</elements>
	</ntdbDiagnostic>
</sch:diagnostic>

  </sch:diagnostics>

</sch:schema>